@@ -1,9 +1,12 @@
 from . import chainApproximation
+from . import chainApproximation_c
 from . import digitization
+from . import aggregation_memview
 from . import aggregation
+from . import fabba_agg_memview
 from . import fabba_agg
 from . import load_datasets
 from . import symbolic_representation
 from .symbolic_representation import *
 from .chainApproximation import *
-from .digitization import *
+from .digitization import *
\ No newline at end of file
